pub enum Event {
KeyPress(Key),
Mouse(Mouse),
Status(Status),
Focus,
FocusLost,
StateChange(StateChange),
}Available on crate features
events and raw only.Expand description
Known terminal event.
Variants
KeyPress(Key)
Key was pressed.
Mouse(Mouse)
Mouse event.
Mouse events are sent only if enabled with one of:
codes::ENABLE_MOUSE_XY_PR_TRACKING: enables events only on mouse press, release and scroll.codes::ENABLE_MOUSE_XY_DRAG_TRACKING: also enables drag events.codes::ENABLE_MOUSE_XY_ALL_TRACKING: also enables move events.
It is recommended to use an extension for better encoding of the
events. The recommended extension is codes::ENABLE_MOUSE_XY_EXT.
Status(Status)
Received terminal attributes.
Usually received after request.
Focus
The terminal has gained focus.
The event may be received only if enabled with
codes::ENABLE_FOCUS_EVENT.
FocusLost
The terminal has lost focus.
The event may be received only if enabled with
codes::ENABLE_FOCUS_EVENT.
StateChange(StateChange)
The input state has changed.
Usually requires to be enabled with feature.